==> magit_2.3.0.orig.tar.gz: magit-2.3.0/README.md <==
<a href="#readme"></a>
<p align="center"><img src="http://magit.vc/img/magit.png"/></p>
<h1 align="center">It's Magit!</h1>
<h2 align="center">A Git Porcelain inside Emacs</h2>
<p align="center">
  <a href="http://magit.vc"><b>homepage</b></a> |
  <a href="http://magit.vc/manual"><b>manual</b></a> |
  <a href="http://magit.vc/manual/magit/FAQ.html"><b>faq</b></a> |
  <a href="https://github.com/magit/magit/wiki"><b>wiki</b></a> |
  <a href="https://groups.google.com/forum/?fromgroups#!forum/magit"><b>mailing list</b></a> |
  <a href="http://emacs.stackexchange.com/questions/tagged/magit"><b>forum</b></a> |
  <a href="https://gitter.im/magit/magit"><b>chat</b></a> |
  <a href="https://twitter.com/magit_emacs"><b>news</b></a>
</p>
***

<p align="justify">
  Magit is an interface to the version control system
  <a href="http://git-scm.com">Git</a>, implemented as an
  <a href="http://www.gnu.org/software/emacs">Emacs</a> package.
  Magit aspires to be a complete Git porcelain.  While we cannot
  (yet) claim that Magit wraps and improves upon each and every Git
  command, it is complete enough to allow even experienced Git users
  to perform almost all of their daily version control tasks directly
  from within Emacs.  While many fine Git clients exist, only Magit
  and Git itself deserve to be called porcelains.
  <a href="http://magit.vc/about.html">(more)</a>
</p>
***

<p align="center">
  <b>
    Please consider supporting development by making a
    <a href="http://magit.vc/donations.html">donation</a>.
  </b>
</p>
***

<p align="center">
  <img src="http://magit.vc/img/r.png" align="top">
  User who haven't read the
  <a href="http://magit.vc/manual/magit/FAQ.html"><b>FAQ</b></a>
  are frequently surprised that:
  <img src="http://magit.vc/img/l.png" align="top">
</p>

- Magit v2.1 and later (aka > 20150701) requires at least
  Emacs v24.4 and Git v1.9.4.
- Branching and pushing in v2.1 no longer behaves like it did in v1.
  This has caused many complains, so branching and pushing will change
  again in v2.4.
- The branch manager has moved to <kbd>y</kbd>.

***

Support
=======

**When something doesn't work as expected then please first see the
[FAQ][faq].** Then also try the list of [open issues][issues] and use
the search box at the top of that page to find older related issues.
You should also consult the [manual][manual] and ask a general-purpose
search engine.

If everything else fails then ask for help on the
**[Emacs Stackexchange site][forum]**, the
[mailing list][list], or the
[Gitter chat][chat].

**Please do NOT use the Github issue tracker for support requests.**
**We only use it for feature requests and bug reports.**

Contributing
============

To report bugs and suggest new feature use the
[issue tracker][issues].  If you have some code which you would like
to be merged, then open a [pull requests][pulls]. Please also see
[CONTRIBUTING.md][contrib].

Acknowledgments
===============

Magit was started by [Marius Vollmer][marius], and is now maintained
by [Jonas Bernoulli][jonas], [Kyle Meyer][kyle], and
[Noam Postavsky][noam].  Other former maintainers are
[Nicolas Dudebout][nicolas], [Peter J. Weisberg][peter],
[Phil Jackson][phil], [Rémi Vanicat][remi], and [Yann Hodique][yann].
Many more people have [contributed code][authors] and suggested
features.

Thanks to all of you, may (the history of) the source be with you!

***
[![Build Status](https://travis-ci.org/magit/magit.svg?branch=master)](https://travis-ci.org/magit/magit)

[contrib]: https://github.com/magit/magit/blob/master/CONTRIBUTING.md
[issues]:  https://github.com/magit/magit/issues
[pulls]:   https://github.com/magit/magit/pulls

[authors]: http://magit.vc/stats/authors.html
[faq]:     http://magit.vc/manual/magit/FAQ.html
[manual]:  http://magit.vc/manual

[chat]:    https://gitter.im/magit/magit
[forum]:   http://emacs.stackexchange.com/questions/tagged/magit
[list]:    https://groups.google.com/forum/?fromgroups#!forum/magit

[jonas]:   http://emacsair.me
[kyle]:    https://github.com/kyleam
[marius]:  https://github.com/mvollmer
[nicolas]: http://dudebout.com
[noam]:    https://github.com/npostavs
[peter]:   https://github.com/pjweisberg
[phil]:    https://github.com/philjackson
[remi]:    https://github.com/vanicat
[yann]:    http://www.hodique.info

==> magit_2.6.0.orig.tar.gz: magit-2.6.0/README.md <==
<p align="center"><img src="https://magit.vc/img/magit.png"/></p>
<h1 align="center">It's Magit!</h1>
<h2 align="center">A Git Porcelain inside Emacs</h2>
<p align="center">
  <a href="https://magit.vc"><b>homepage</b></a> |
  <a href="https://magit.vc/manual"><b>manual</b></a> |
  <a href="https://magit.vc/manual/magit/FAQ.html"><b>faq</b></a> |
  <a href="https://github.com/magit/magit/wiki"><b>wiki</b></a> |
  <a href="https://groups.google.com/forum/?fromgroups#!forum/magit"><b>mailing list</b></a> |
  <a href="https://emacs.stackexchange.com/questions/tagged/magit"><b>forum</b></a> |
  <a href="https://gitter.im/magit/magit"><b>chat</b></a> |
  <a href="https://twitter.com/magit_emacs"><b>news</b></a>
</p>
***

<p align="justify">
  Magit is an interface to the version control system
  <a href="https://git-scm.com">Git</a>, implemented as an
  <a href="https://www.gnu.org/software/emacs">Emacs</a> package.
  Magit aspires to be a complete Git porcelain.  While we cannot
  (yet) claim that Magit wraps and improves upon each and every Git
  command, it is complete enough to allow even experienced Git users
  to perform almost all of their daily version control tasks directly
  from within Emacs.  While many fine Git clients exist, only Magit
  and Git itself deserve to be called porcelains.
  <a href="https://magit.vc/about.html">(more)</a>
</p>
***

<p align="center">
  <b>
    Please consider supporting development by making a
    <a href="https://magit.vc/donations.html">donation</a>.
  </b>
  </br></br>
  <a href="https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=TGDUK5VGB78XA">
    <img alt="Donate" src="https://www.paypalobjects.com/en_US/i/btn/btn_donateCC_LG.gif">
  </a>
  </br>
  <a class="small" href="https://magit.vc/donations.html">(other donation methods)</a>
</p>
***

Support
=======

When something doesn't work as expected then please first see the
[FAQ][faq].  Then also try the list of [open issues][issues] and use
the search box at the top of that page to find older related issues.
You should also consult the [manual][manual] and ask a general-purpose
search engine.

If that doesn't answer your question, then ask for help on the
**[Emacs Stackexchange site][forum]**, the [mailing list][list], or
the [Gitter chat][chat].

**Please do NOT use the GitHub issue tracker for support requests.**
**We only use it for feature requests and bug reports.**

Contributing
============

To report bugs and suggest new feature use the
[issue tracker][issues].  If you have some code which you would like
to be merged, then open a [pull request][pulls]. Please also see
[CONTRIBUTING.md][contrib].

Acknowledgments
===============

Magit was started by [Marius Vollmer][marius], and is now maintained
by [Jonas Bernoulli][jonas], [Kyle Meyer][kyle], and
[Noam Postavsky][noam].  Other former maintainers are
[Nicolas Dudebout][nicolas], [Peter J. Weisberg][peter],
[Phil Jackson][phil], [Rémi Vanicat][remi], and [Yann Hodique][yann].
Many more people have [contributed code][authors] and suggested
features.

Thanks to all of you, may (the history of) the source be with you!

***
[![Build Status](https://travis-ci.org/magit/magit.svg?branch=master)](https://travis-ci.org/magit/magit)

[contrib]: https://github.com/magit/magit/blob/master/CONTRIBUTING.md
[issues]:  https://github.com/magit/magit/issues
[pulls]:   https://github.com/magit/magit/pulls

[authors]: https://magit.vc/stats/authors.html
[faq]:     https://magit.vc/manual/magit/FAQ.html
[manual]:  https://magit.vc/manual

[chat]:    https://gitter.im/magit/magit
[forum]:   https://emacs.stackexchange.com/questions/tagged/magit
[list]:    https://groups.google.com/forum/?fromgroups#!forum/magit

[jonas]:   https://emacsair.me
[kyle]:    https://github.com/kyleam
[marius]:  https://github.com/mvollmer
[nicolas]: http://dudebout.com
[noam]:    https://github.com/npostavs
[peter]:   https://github.com/pjweisberg
[phil]:    https://github.com/philjackson
[remi]:    https://github.com/vanicat
[yann]:    http://www.hodique.info
